// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;

/**
 * Container for channel information.
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class Channel
    extends ContainerBase //
{
    final
    private LinkedList itemList_ = new LinkedList();

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     */
    public Channel(){
    }

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Add item to channel.
     *
     * @param item to be added
     */
    final
    public void addItem(Item item){ itemList_.add(item); }

    /**
     * Get item identified by id.
     *
     * @param id of item
     * @return item if found, or null otherwise
     */
    final
    public Item getItem(String id){
        Iterator items = itemList_.iterator();
        while(items.hasNext()){
            Item item = (Item)(items.next());
            if(item.getID().equals(id)){ return item; }
        }
        return null;
    }

    /**
     * Get iterator of items contained by channel.
     *
     * @return iterator of items
     */
    final
    public Iterator getItems(){
        return Collections.unmodifiableList(itemList_).iterator();
    }
}
