// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ContainerAdapter;
import java.awt.event.ContainerEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.CharArrayWriter;
import java.io.PrintWriter;
import java.util.Iterator;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

/**
 * Frame for SASAX-RSS GUI.
 *
 * <p>This is bootstrap class for RSS reader GUI.</p>
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class GUI
    extends JFrame //
{
    final
    private RootPane rootPane_ = new RootPane();

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     */
    public GUI(){
        super("RSS reader");

        rootPane_.load.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent e){
                Runnable procedure = new Runnable(){
                    public void run(){ loadRSS(); }
                };
                Thread thread = new Thread(procedure);
                thread.start();
            }
        });

        this.getContentPane().add(rootPane_);
        this.pack();
    }

    ///////////////////////////////////////////////////////////////////////////

    private void loadRSS(){
        rootPane_.load.setEnabled(false); // disable
        Channel channel;
        try{
            channel = ChannelFactory.create(rootPane_.uri.getText());
        }
        catch(Exception e){
            CharArrayWriter writer = new CharArrayWriter();
            PrintWriter pWriter = new PrintWriter(writer);
            e.printStackTrace(pWriter);
            pWriter.flush();

            JTextArea errorText = new JTextArea(writer.toString());
            errorText.setEditable(false);
            errorText.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 12));
            JScrollPane viewPort = new JScrollPane(errorText);
            viewPort.setPreferredSize(new Dimension(320, 240));

            JOptionPane.showMessageDialog(this,
                                          viewPort,
                                          "SASAX-RSS GUI error",
                                          JOptionPane.ERROR_MESSAGE);
            return;
        }
        finally{
            rootPane_.load.setEnabled(true); // enable
        }

        int num = rootPane_.getTabCount();
        for(int i = num - 1 ; 0 < i ; i -= 1){
            rootPane_.removeTabAt(i);
        }
        {
            ChannelPane pane = new ChannelPane(channel);
            rootPane_.addTab(trim(channel.getString(ValueID.TITLE), 8),
                             null,
                             pane,
                             channel.getString(ValueID.TITLE));
        }
        Iterator items = channel.getItems();
        while(items.hasNext()){
            Item item = (Item)(items.next());
            ItemPane pane = new ItemPane(item);
            rootPane_.addTab(trim(item.getString(ValueID.TITLE), 8),
                             null,
                             pane,
                             item.getString(ValueID.TITLE));
        }

        pack();
    }

    ////////////////////////////////////////

    static
    private String trim(String string, int length){
        if(string.length() <= length){
            return string;
        }
        StringBuffer buffer =
        new StringBuffer(string.substring(0, length - 3));
        buffer.append("...");
        return buffer.toString();
    }

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Bootstrap method.
     */
    static
    public void main(String[] args){
        GUI gui = new GUI();
        gui.addWindowListener(new WindowAdapter(){
	    public void windowClosing(WindowEvent e){
                System.exit(0);
            }
	});
        gui.show();
    }
}
