// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import jp.ne.dti.lares.foozy.sasax.Element;
import jp.ne.dti.lares.foozy.sasax.Notification;
import jp.ne.dti.lares.foozy.sasax.ParseContext;

/**
 * Listener to set information up from parse result of "rdf:li" element.
 *
 * <p>This expects to be added to <code>RDFLiElement</code>.</p>
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class RDFLiNotification
    implements Notification //
{
    final
    private Channel channel_;

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     *
     * @param channel into which information is stored
     */
    public RDFLiNotification(Channel channel){
        channel_ = channel;
    }

    ///////////////////////////////////////////////////////////////////////////
    // Implementation of interface Notification

    /**
     * Invoked when target element is "started".
     *
     * <p>This adds {@link Item} created with
     * "rdf:resource" attribute value as ID
     * to channel,
     * which is specified at construction time.</p>
     *
     * @param element which is started
     * @param context of SAX document parsing.
     * @param attrs given by "startElement" SAX event.
     */
    public void elementStarted(Element element,
                               ParseContext context,
                               Attributes attributes)
        throws SAXException //
    {
        String id = attributes.getValue(RDF.NS_URI, RDF.RESOURCE);
        Item item = new Item(id);
        channel_.addItem(item);
    }

    /**
     * Invoked when target element is "ended".
     *
     * <p>This does nothing.</p>
     *
     * @param element which is ended
     * @param context of SAX document parsing.
     */
    public void elementEnded(Element element,
                             ParseContext context)
        throws SAXException //
    {
        // NOP
    }
}
